@@ -125,7 +125,11 @@ class MongoFile(RawIOBase):
 			else:
 				self.seek(limit, SEEK_CUR)
 			newpos = self.tell()
-			return str(result[pos:newpos])
+			result = result[pos:newpos]
+			try:
+				return bytes(result)
+			except UnicodeEncodeError:
+				return result
 		else:
 			raise IOError("MongoFile '%s' is not readable." % self.name)
 	def readable(self):
@@ -162,7 +166,6 @@ class MongoFile(RawIOBase):
 		Return the number of bytes written.
 		"""
 		if self.writable():
-			data = data.encode('ascii')
 			size = len(data)
 			self.collection.insert({
 				"name": self.name,
